# Generated by Django 3.1.3 on 2020-11-28 22:45

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('voice_bot', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='command',
            name='trigger_words',
            field=models.CharField(default='', help_text='Code words for executing the command. Sets of code words must be separated by a comma, and code words in the set must be separated by a space.', max_length=1000),
        ),
        migrations.AlterField(
            model_name='command',
            name='bot',
            field=models.ForeignKey(help_text='bot that will execute the command', on_delete=django.db.models.deletion.CASCADE, to='voice_bot.bot', to_field='name'),
        ),
        migrations.AlterField(
            model_name='command',
            name='redirect_url',
            field=models.CharField(help_text="Link or name of the page on the site to be redirected to. For an external page — it must start with 'www', otherwise the link will be recognized as the template name.", max_length=150),
        ),
    ]
