# Generated by Django 3.1.3 on 2020-11-29 03:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('voice_bot', '0005_auto_20201129_0635'),
    ]

    operations = [
        migrations.AddField(
            model_name='command',
            name='requests_headers',
            field=models.CharField(blank=True, default='', help_text='request headers,should be written as json', max_length=500),
        ),
        migrations.AlterField(
            model_name='command',
            name='api_header',
            field=models.CharField(blank=True, default='', help_text='API header, that will be used to extract data', max_length=200),
        ),
        migrations.AlterField(
            model_name='command',
            name='api_url',
            field=models.CharField(blank=True, default='', help_text='API URL to update message', max_length=150),
        ),
        migrations.AlterField(
            model_name='command',
            name='message',
            field=models.CharField(blank=True, default='', help_text='Custom message that will be displayed when the command is executed. Leave empty for the default option', max_length=500),
        ),
    ]
