# Generated by Django 3.1.3 on 2020-11-29 02:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('voice_bot', '0003_bot_speech_full'),
    ]

    operations = [
        migrations.AddField(
            model_name='bot',
            name='failure_messages',
            field=models.CharField(default='ok', help_text='Bot failure messages, should be splitten with comma', max_length=500),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='bot',
            name='success_messages',
            field=models.CharField(default='ok', help_text='Bot success messages, should be splitten with comma', max_length=500),
            preserve_default=False,
        ),
    ]
