# Generated by Django 3.1.3 on 2020-11-29 05:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('voice_bot', '0006_auto_20201129_0657'),
    ]

    operations = [
        migrations.AddField(
            model_name='bot',
            name='repeat_commands',
            field=models.IntegerField(choices=[(0, "Don't repeat all commands on failure"), (1, 'Repeat all commands on failure')], default=0),
        ),
    ]
