# Generated by Django 3.1.3 on 2020-11-28 21:45

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Bot',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(blank=True, max_length=1000)),
                ('language', models.IntegerField(choices=[(0, 'Русский'), (1, 'English'), (2, 'Deutsch'), (3, 'Francias')])),
                ('name', models.CharField(max_length=100, unique=True)),
            ],
        ),
        migrations.CreateModel(
            name='Command',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=500)),
                ('redirect_url', models.CharField(max_length=150)),
                ('bot', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='voice_bot.bot', to_field='name')),
            ],
        ),
    ]
