# Generated by Django 3.1.3 on 2020-11-29 01:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('voice_bot', '0002_auto_20201129_0145'),
    ]

    operations = [
        migrations.AddField(
            model_name='bot',
            name='speech_full',
            field=models.IntegerField(choices=[(0, 'Speech only first trigger'), (1, 'Speech all triggers')], default=0),
            preserve_default=False,
        ),
    ]
